<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Tourable Pro
 * @since Tourable Pro 1.0.0
 */

if ( ! function_exists( 'tourable_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Tourable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function tourable_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'tourable_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'tourable_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Tourable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function tourable_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'tourable_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'tourable_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Tourable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function tourable_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'tourable_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'tourable_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Tourable Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function tourable_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[slider_content_type]' )->value();
	return tourable_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[slider_content_type]' )->value();
	return tourable_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[slider_content_type]' )->value();
	return tourable_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[service_content_type]' )->value();
	return tourable_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[service_content_type]' )->value();
	return tourable_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[service_content_type]' )->value();
	return tourable_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[service_content_type]' )->value();
	return tourable_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if trip search section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_trip_search_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[trip_search_section_enable]' )->value() );
}

/**
 * Check if destinations section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_destinations_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[destinations_section_enable]' )->value() );
}

/**
 * Check if destinations section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_destinations_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[destinations_content_type]' )->value();
	return tourable_pro_is_destinations_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if destinations section content type is trip types.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_destinations_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[destinations_content_type]' )->value();
	return tourable_pro_is_destinations_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if destinations section content type is destination.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_destinations_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[destinations_content_type]' )->value();
	return tourable_pro_is_destinations_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if destinations section content type is activity.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_destinations_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[destinations_content_type]' )->value();
	return tourable_pro_is_destinations_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[cta_content_type]' )->value();
	return tourable_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[cta_content_type]' )->value();
	return tourable_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[cta_content_type]' )->value();
	return tourable_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if traveler choice section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_section_enable]' )->value() );
}

/**
 * Check if traveler choice section content type is page.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if traveler choice section content type is post.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if traveler choice section content type is trip.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if traveler choice section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if traveler choice section content type is trip types.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if traveler choice section content type is destination.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if traveler choice section content type is activity.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_traveler_choice_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[traveler_choice_content_type]' )->value();
	return tourable_pro_is_traveler_choice_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if popular destination section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[popular_destination_content_type]' )->value();
	return tourable_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if activities section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_activities_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[activities_section_enable]' )->value() );
}

/**
 * Check if activities section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_activities_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[activities_content_type]' )->value();
	return tourable_pro_is_activities_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if activities section content type is trip types.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_activities_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[activities_content_type]' )->value();
	return tourable_pro_is_activities_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if activities section content type is destination.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_activities_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[activities_content_type]' )->value();
	return tourable_pro_is_activities_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if activities section content type is activity.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_activities_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[activities_content_type]' )->value();
	return tourable_pro_is_activities_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'tourable_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[blog_content_type]' )->value();
	return tourable_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[blog_content_type]' )->value();
	return tourable_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[blog_content_type]' )->value();
	return tourable_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Tourable Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function tourable_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'tourable_pro_theme_options[blog_content_type]' )->value();
	return tourable_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}


