<?php
/**
 * Activities section
 *
 * This is the template for the content of activities section
 *
 * @package Theme Palace
 * @subpackage Tourable Pro
 * @since Tourable Pro 1.0.0
 */
if ( ! function_exists( 'tourable_pro_add_activities_section' ) ) :
    /**
    * Add activities section
    *
    *@since Tourable Pro 1.0.0
    */
    function tourable_pro_add_activities_section() {
    	$options = tourable_pro_get_theme_options();
        // Check if activities is enabled on frontpage
        $activities_enable = apply_filters( 'tourable_pro_section_status', true, 'activities_section_enable' );

        if ( true !== $activities_enable ) {
            return false;
        }
        // Get activities section details
        $section_details = array();
        $section_details = apply_filters( 'tourable_pro_filter_activities_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render activities section now.
        tourable_pro_render_activities_section( $section_details );
    }
endif;

if ( ! function_exists( 'tourable_pro_get_activities_section_details' ) ) :
    /**
    * activities section details.
    *
    * @since Tourable Pro 1.0.0
    * @param array $input activities section details.
    */
    function tourable_pro_get_activities_section_details( $input ) {
        $options = tourable_pro_get_theme_options();

        // Content type.
        $activities_content_type  = $options['activities_content_type'];
        $activities_count = ! empty( $options['activities_count'] ) ? $options['activities_count'] : 3;
        
        $content = array();
        switch ( $activities_content_type ) {
        	
            case 'category':
                $cat_ids = array();

                for ( $i = 1; $i <= $activities_count; $i++ ) {
                    if ( ! empty( $options['activities_content_category_' . $i] ) ) :
                        $cat_ids['id'] = $options['activities_content_category_' . $i];
                        $cat_ids['image'] = ! empty( $options['activities_background_image_' . $i] ) ? $options['activities_background_image_' . $i] : '';
                        $cat = get_category( $cat_ids['id'] );
                        $cat_ids['title'] = $cat->name;
                        $cat_ids['count'] = $cat->category_count;
                        $cat_ids['url'] = get_category_link( $cat_ids['id'] );
                    endif;

                    if ( ! empty( $options['activities_content_category_' . $i] ) )
                        array_push( $content, $cat_ids );
                }                
            break;

            case 'trip-types':
                $cat_ids = array();

                for ( $i = 1; $i <= $activities_count; $i++ ) {
                    if ( ! empty( $options['activities_content_trip_types_' . $i] ) ) :
                        $cat_ids['id'] = $options['activities_content_trip_types_' . $i];
                        $cat_ids['image'] = ! empty( $options['activities_background_image_' . $i] ) ? $options['activities_background_image_' . $i] : '';
                        $cat = get_term_by( 'id', $cat_ids['id'], 'itinerary_types' );
                        $cat_ids['title'] = $cat->name;
                        $cat_ids['count'] = $cat->count;
                        $cat_ids['url'] = get_term_link( $cat_ids['id'], 'itinerary_types' );       
                    endif;

                    if ( ! empty( $options['activities_content_trip_types_' . $i] ) )
                        array_push( $content, $cat_ids );
                }                
            break;

            case 'destination':
                $cat_ids = array();

                for ( $i = 1; $i <= $activities_count; $i++ ) {
                    if ( ! empty( $options['activities_content_destination_' . $i] ) ) :
                        $cat_ids['id'] = $options['activities_content_destination_' . $i];
                        $cat_ids['image'] = ! empty( $options['activities_background_image_' . $i] ) ? $options['activities_background_image_' . $i] : '';
                        $cat = get_term_by( 'id', $cat_ids['id'], 'travel_locations' );
                        $cat_ids['title'] = $cat->name;
                        $cat_ids['count'] = $cat->count;
                        $cat_ids['url'] = get_term_link( $cat_ids['id'], 'travel_locations' );
                    endif;

                    if ( ! empty( $options['activities_content_destination_' . $i] ) )
                        array_push( $content, $cat_ids );
                }                
            break;

            case 'activity':
                $cat_ids = array();

                for ( $i = 1; $i <= $activities_count; $i++ ) {
                    if ( ! empty( $options['activities_content_activity_' . $i] ) ) :
                        $cat_ids['id'] = $options['activities_content_activity_' . $i];
                        $cat_ids['image'] = ! empty( $options['activities_background_image_' . $i] ) ? $options['activities_background_image_' . $i] : '';
                        $cat = get_term_by( 'id', $cat_ids['id'], 'activity' );
                        $cat_ids['title'] = $cat->name;
                        $cat_ids['count'] = $cat->count;
                        $cat_ids['url'] = get_term_link( $cat_ids['id'], 'activity' );
                    endif;

                    if ( ! empty( $options['activities_content_activity_' . $i] ) )
                        array_push( $content, $cat_ids );
                }                
            break;

            default:
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// activities section content details.
add_filter( 'tourable_pro_filter_activities_section_details', 'tourable_pro_get_activities_section_details' );


if ( ! function_exists( 'tourable_pro_render_activities_section' ) ) :
  /**
   * Start activities section
   *
   * @return string activities content
   * @since Tourable Pro 1.0.0
   *
   */
   function tourable_pro_render_activities_section( $content_details = array() ) {
        $options = tourable_pro_get_theme_options();
        $suffix = ! empty( $options['activities_suffix'] ) ? $options['activities_suffix'] : '';
        $class = ( count( $content_details ) > 3 ) ? 'modern-slider' : 'classic-slider';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="discover-places" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php if ( ! empty( $options['activities_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['activities_title'] ); ?></h2>
                    <?php endif; 

                    if ( ! empty( $options['activities_sub_title'] ) ) : ?>
                        <span class="section-subtitle"><?php echo esc_html( $options['activities_sub_title'] ) ?></span>
                    <?php endif; ?>
                </div><!-- .section-header -->
            </div><!-- .wrapper -->

            <div class="destination-slider <?php echo esc_attr( $class ); ?>" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false }'>
                <?php foreach ( $content_details as $content ) : ?>
                    <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            <span>
                                <?php 
                                    echo absint( $content['count'] ); 
                                    echo ' ' . esc_html( $suffix );
                                ?>
                            </span>
                        </header>
                    </article>
                <?php endforeach; ?>
            </div><!-- .destination-slider -->

            <?php if ( ! empty( $options['activities_btn_title'] ) && ! empty( $options['activities_btn_url'] ) ) : ?>
                <div class="read-more">
                    <a href="<?php echo esc_url( $options['activities_btn_url'] ) ?>" class="btn btn-transparent"><?php echo esc_html( $options['activities_btn_title'] ); ?></a>
                </div><!-- .read-more -->
            <?php endif; ?>
        </div><!-- #discover-places -->
    <?php }
endif;